##  Navigating the Dashboard
The dashboard serves as a dynamic data funnel, allowing you to filter and drill down through various levels of data. After configuring the dashboard and creating views, you can select these views to limit the scope of data used in KPI calculations, focusing on the datasets you need. To learn how to navigate the dashboard step by step, visit [Navigating the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/navigate-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how data on the dashboard is structured and how to navigate the dashboard to gain insights.").
